Hi! I download and send audios from videos/tracks/sets/albums in *MP3 128 kbps* with tags and artwork. Files over 50 MB are split into parts due to Telegram Bot API limit.

*Usage:*
_Send or forward_ a text message containing links and I will:
• In *Download* mode: download every link I support (or use `/dl <links>`)
• In *Links* mode: show direct download URLs for every link (or use `/link <links>`)
• In *Ask* mode: scan for supported links and ask you to choose download or links
• Use /settings to select working mode for messages *without command*.
• Use /settings to toggle *Captions*.
• [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_, so I scan every group message.
• Supported links and resources:
*SoundCloud*: tracks/playlists/pages with private widgets
*Bandcamp*: tracks/albums/custom links
*YouTube*: videos/playlists/not lives
*Mixcloud, Vimeo and* [everything from this list](https://rg3.github.io/youtube-dl/supportedsites.html) (no VK music)

*Example message:*
`Hey, bruh, check it out! https://m.soundcloud.com/richarddjames/umil-25-01 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix and youtu.be/Mdzy5RKn434`

*Credits | Emoji-links:*
[🌟 @GitHub](https://github.com/gpchelkin/scdlbot) | [⌨️⚠](https://github.com/gpchelkin/scdlbot/issues)
👨🏻‍💻 @gpchelkin | [🐝👍](http://pchelk.in/)
👩🏻‍🎨 @lowonbudget | [🎨🖼️](https://www.behance.net/lowonbudget)
🎶 @electrocircle | [⚡⚫](https://t.me/Eklight)
